# floodlight analysis tool, version 0.4, nov 12 2020
shinyServer <- function(input, output, session) {
  # ... your other server code here
  observeEvent(input$file_1, {
    d01 <- fread(file = input$file_1$datapath)
    output$choose_vars <- renderUI({
      fluidRow(
        column(
          4,
          selectizeInput(
            inputId = "dv",
            label = "Choose the Dependent Variable:",
            choices = names(d01),
            multiple = F,
            options = list(maxOptions = shiny_list_max))),
        column(
          4,
          selectizeInput(
            inputId = "iv",
            label = "Choose the Independent Variable:",
            choices = names(d01),
            multiple = F,
            options = list(maxOptions = shiny_list_max))),
        column(
          4,
          selectizeInput(
            inputId = "mod",
            label = "Choose the Moderating Variable:",
            choices = names(d01),
            multiple = F,
            options = list(maxOptions = shiny_list_max))))
    })
  })
  observeEvent(input$mod, {
    req(input$mod)
    output$x_axis_label <- renderUI({
      textInput(
        inputId = "x_axis_label",
        label = "X Axis Title:",
        value = input$mod)})
  })
  observeEvent(input$dv, {
    output$y_axis_label <- renderUI({
      textInput(
        inputId = "y_axis_label",
        label = "Y Axis Title:",
        value = input$dv)})
  })
  observeEvent(input$iv, {
    output$legend_title <- renderUI({
      textInput(
        inputId = "legend_title",
        label = "Legend Title:",
        value = input$iv)})
  })
  # view data
  observeEvent(input$view_data_btn, {
    # clear the plot
    output$plot_1 <- NULL
    # display uploaded file
    output$data_contents <- renderTable({
      # input$file_1 will be NULL initially. After the user selects
      # and uploads a file, head of that data file by default,
      # or all rows if selected, will be shown.
      req(input$file_1)
      tryCatch(
        {d01 <- fread(file = input$file_1$datapath)},
        error = function(e) {
          # return a safeError if a parsing error occurs
          stop(safeError(e))
        })
      if(input$disp == "first_5") {
        return(head(d01, n = 5))
      }
      else {
        return(d01)
      }
    })
  })
  # plot it
  observeEvent(input$plot_it_btn, {
    # clear the table
    output$data_contents <- NULL
    # create the plot
    output$plot_1 <- renderPlot({
      req(input$file_1)
      d01 <- fread(file = input$file_1$datapath)
      d02 <- na.omit(
        d01[, c(input$iv, input$mod, input$dv), with = F])
      names(d02) <- c("iv", "mod", "dv")
      # plot
      g1 <- two_by_continuous_w_jn_points_plot(
        data = d02,
        iv_name = "iv",
        dv_name = "dv",
        mod_name = "mod",
        output = input$plot_type,
        jitter_x_as_percentage = input$x_jitter_percent,
        jitter_y_as_percentage = input$y_jitter_percent,
        dot_alpha = input$dot_alpha / 100,
        dot_size = input$dot_size,
        legend_position = input$legend_position,
        range_limited_to_observed = T,
        reg_line_types = input$reg_line_types,
        jn_line_types = input$jn_line_types,
        sig_area_color = input$sig_area_color,
        sig_area_alpha = input$sig_area_alpha / 100,
        nonsig_area_color = input$nonsig_area_color,
        nonsig_area_alpha = input$nonsig_area_alpha / 100)
      g1 <- g1 + labs(
        color = input$legend_title,
        linetype = input$legend_title)
      # isolate({
      # x axis tick marks
      if(input$x_axis_tick_marks != "") {
        x_ticks_entered <- input$x_axis_tick_marks
        x_ticks_numbers_only <-
          comma_separated_character_to_numbers(x_ticks_entered)
        g1 <- g1 + scale_x_continuous(
          limits = c(min(x_ticks_numbers_only),
                     max(x_ticks_numbers_only)),
          breaks = x_ticks_numbers_only)
      }
      # y axis tick marks
      if(input$y_axis_tick_marks != "") {
        y_ticks_entered <- input$y_axis_tick_marks
        y_ticks_numbers_only <-
          comma_separated_character_to_numbers(y_ticks_entered)
        g1 <- g1 + scale_y_continuous(
          limits = c(min(y_ticks_numbers_only),
                     max(y_ticks_numbers_only)),
          breaks = y_ticks_numbers_only)
      }
      # })
      # axis labels
      g1 <- g1 + xlab(input$x_axis_label)
      g1 <- g1 + ylab(input$y_axis_label)
      return(g1)
    })
    # update plot on the dynamic ui
    output$plot_1_ui <- renderUI({
      plotOutput(
        "plot_1", 
        width = input$plot_width,
        height = input$plot_height)
    })
  })
  # close the R session when Chrome closes
  session$onSessionEnded(function() { 
    stopApp()
    q("no") 
  })
}