# floodlight analysis tool, version 0.4, nov 12 2020

# define ui for data upload app
ui <- fluidPage(
  # style
  tags$head(
    tags$style(HTML(
      "#view_data_btn{
    margin-top: 25px;}
    #plot_it_btn{
    height: 100px;
    margin-top: 40px}"))),
  # app title
  titlePanel(
    "Floodlight Analysis Tool by Jin Kim (2020), v0.4"),
  # sidebar layout with input and output definitions
  sidebarLayout(
    # sidebar for inputs
    sidebarPanel(
      # give credit
      h4(paste0(
        "This tool has not been tested thoroughly. ", 
        "Please read Spiller et al. (2013) ",
        "and use at your own risk.")),
      h4(paste0(
        "This tool is created based on ",
        "Spiller et al. (2013); ",
        "Johnson & Neyman (1936); ",
        "Preacher et al. (2006); ",
        "Aiken & West (1991); ",
        "Rogosa (1980, 1981); ",
        "Long (2020); ",
        "Wickham et al. (2020); ",
        "Chang et al. (2020)")),
      # add a horizontal line
      tags$hr(),
      fluidRow(
        column(
          6,
          # file input
          fileInput(
            "file_1", "Choose a CSV file:",
            multiple = FALSE,
            accept = c(
              "text/csv",
              "text/comma-separated-values,text/plain",
              ".csv"))),
        column(
          4, 
          # select number of rows to display
          radioButtons(
            "disp", "Rows to display when viewing data:",
            choices = c("First 5" = "first_5",
                        "All" = "all"),
            selected = "first_5",
            inline = T)),
        column(
          2,
          actionButton(
            inputId = "view_data_btn", 
            label = "View data",
            width = "100%",
            height = "100%",
            style = "font-size: 18px"))),
      # add a horizontal line
      tags$hr(),
      radioButtons(
        "plot_type", "Choose a plot type:",
        choices = c(
          "Regression Lines" = "reg_lines_plot", 
          "Estimated Simple Effects" = "simple_effects_plot"),
        selected = "reg_lines_plot",
        inline = T),
      tags$hr(),
      uiOutput("choose_vars"),
      fluidRow(
        column(4, uiOutput("y_axis_label")),
        column(4, uiOutput("legend_title")),
        column(4, uiOutput("x_axis_label"))),
      tags$hr(),
      fluidRow(
        column(
          2, 
          numericInput(
            inputId = "plot_width",
            label = "Plot width (px):",
            value = plot_width_default_value)),
        column(
          5,
          numericInput(
            inputId = "x_jitter_percent",
            label = "Jitter dots horizontally by ___% of the range:",
            value = x_jitter_percent)),
        column(
          5,
          sliderInput(
            inputId = "dot_alpha",
            label = "Transparency of dots (0% - 100%):",
            min = 0,
            max = 100,
            value = dot_alpha))),
      fluidRow(
        column(
          2,
          numericInput(
            inputId = "plot_height",
            label = "Plot height (px):",
            value = plot_height_default_value)),
        column(
          5,
          numericInput(
            inputId = "y_jitter_percent",
            label = "Jitter dots vertically by ___% of the range:",
            value = y_jitter_percent)),
        column(
          5,
          fluidRow(
            column(
              4, 
              numericInput(
                inputId = "dot_size",
                label = "Size of dots:",
                value = dot_size)),
            column(
              8, 
              selectizeInput(
                inputId = "legend_position",
                label = "Choose position of legend:",
                choices = c("none", "top", "right", "bottom", "left"),
                multiple = F,
                selected = legend_position))))),
      fluidRow(
        column(
          4,
          selectizeInput(
            inputId = "reg_line_types",
            label = "Choose types of regression lines:",
            choices = c(
              "twodash", "solid", "longdash", "dotted", 
              "dotdash", "dashed"),
            multiple = T,
            selected = reg_line_types_default_value)),
        column(
          8,
          textInput(
            inputId = "x_axis_tick_marks",
            label = paste0(
              "Tick marks for X axis (Enter numbers separated",
              ' by commas, e.g., "1,5,9") :'),
            value = ""))),
      fluidRow(
        column(
          4,
          selectizeInput(
            inputId = "jn_line_types",
            label = "Choose line types for JN points:",
            choices = c(
              "twodash", "solid", "longdash", "dotted", 
              "dotdash", "dashed"),
            multiple = T,
            selected = jn_line_types_default_value)),
        column(
          8,
          textInput(
            inputId = "y_axis_tick_marks",
            label = paste0(
              "Tick marks for Y axis (Enter numbers separated",
              ' by commas, e.g., "1,5,9") :'),
            value = ""))),
      fluidRow(
        column(
          3,
          textInput(
            inputId = "sig_area_color",
            label = "Color for significant area:",
            value = sig_area_color),
          textInput(
            inputId = "nonsig_area_color",
            label = "Color for nonsignificant area:",
            value = nonsig_area_color)),
        column(
          6,
          sliderInput(
            inputId = "sig_area_alpha",
            label = 
              "Transparency of significant area color (0% - 100%):",
            min = 0,
            max = 100,
            value = sig_area_alpha),
          sliderInput(
            inputId = "nonsig_area_alpha",
            label = 
              "Transparency of nonsignificant area color (0% - 100%):",
            min = 0,
            max = 100,
            value = nonsig_area_alpha)),
        column(
          3,
          actionButton(
            inputId = "plot_it_btn", 
            label = "Plot it", width = "100%",
            style = "font-size: 35px")))),
    # main panel for displaying outputs
    mainPanel(
      # view content of uploaded data
      tableOutput("data_contents"),
      # plot area
      uiOutput("plot_1_ui")
    )
  )
)